//
// Created by Falko Alrik Schmidt on 26.09.23.
//

#ifndef UULM_WEATHERBALOON_ARDUINO_FRAMEWORK_TEST_ULM_MS5607_H
#define UULM_WEATHERBALOON_ARDUINO_FRAMEWORK_TEST_ULM_MS5607_H

#include "MS5x.h"
#include "Ulm_Beginnable.h"

/**
 * This class represents altitude sensors of type MS5607.
 *
 * @author Falko Schmidt
 * @since 1.0
 */
class Ulm_MS5607 : MS5x, public Ulm_Beginnable {

public:
    /**
     * Constructor.
     * @param address the i2c address of MS5607 sensor.
     * @param aWire the i2c connection, defaults to {@code &Wire}.
     */
    explicit Ulm_MS5607(int8_t address, TwoWire *aWire = &Wire);

    /**
     * Initializes the sensor.
     * @return {@code true} on success, {@code false} otherwise.
     */
    bool begin() override;

    /**
     * Reads out the pressure in mBar.
     * @return the atmospheric pressure in mBar.
     */
    double getPressure();

    /**
     * Reads the temperature in Celsius.
     * @return the temperature in celsius.
     */
    double getTemperature();

    /**
     * Calculates the altitude from the read pressure.
     * This method will use temperature correction.
     * @return the altitude in meters.
     */
    double getAltitude();
};


#endif //UULM_WEATHERBALOON_ARDUINO_FRAMEWORK_TEST_ULM_MS5607_H
